@@ -60,12 +60,12 @@ __use_ini_name__ = "neofile.ini"
 __program_name__ = "PyNeoFile"
 __project__ = __program_name__
 __project_url__ = "https://github.com/GameMaker2k/PyNeoFile"
-__version_info__ = (0, 20, 0, "RC 1", 1)
-__version_date_info__ = (2025, 8, 18, "RC 1", 1)
+__version_info__ = (0, 20, 8, "RC 1", 1)
+__version_date_info__ = (2025, 9, 16, "RC 1", 1)
 __version_date__ = str(__version_date_info__[0]) + "." + str(
     __version_date_info__[1]).zfill(2) + "." + str(__version_date_info__[2]).zfill(2)
 __revision__ = __version_info__[3]
-__revision_id__ = "$Id: 501a60c2a61aed8bd921c555e3f885eed3b101b6 $"
+__revision_id__ = "$Id: 9d99dc742fb061f1486f483f42d795ebfa1f77c8 $"
 if(__version_info__[4] is not None):
     __version_date_plusrc__ = __version_date__ + \
         "-" + str(__version_date_info__[4])
@@ -93,6 +93,19 @@ def _normalize_algo(algo):
         return 'auto'
     return a
 
+def _normalize_ver_digits(ver_text):
+    """
+    Make the on-disk version match Archive's strict header check:
+    - remove dots
+    - strip leading zeros by int() cast when numeric
+    Falls back to the raw digits if not purely numeric.
+    """
+    raw = ver_text.replace(".", "")
+    try:
+        return str(int(raw))  # "001" -> "1"
+    except ValueError:
+        return raw            # keep as-is if not numeric
+
 def _compress_bytes(data, algo='none', level=None):
     """Return (stored_bytes, used_algo)."""
     algo = _normalize_algo(algo)
@@ -440,7 +453,7 @@ def _load_formatspecs_from_ini(paths=None, prefer_section=None):
     ext   = _get('extension', '.neo')
 
     delim_real = _decode_delim_escape(delim)
-    ver_digits = _ver_digits(ver)
+    ver_digits = _normalize_ver_digits(_ver_digits(ver))
 
     spec = {
         'format_magic': magic,
@@ -511,7 +524,7 @@ def _checksum(data, cstype, text=False):
 def _write_global_header(fp, numfiles, encoding, checksumtype, extradata, formatspecs):
     delim = formatspecs['format_delimiter']
     magic = formatspecs['format_magic']
-    ver_digits = _ver_digits(formatspecs.get('format_ver','001'))
+    ver_digits = _normalize_ver_digits(_ver_digits(formatspecs.get('format_ver','001')))
 
     # extras blob: count + items
     if isinstance(extradata, dict) and extradata:
@@ -682,6 +695,14 @@ def _parse_global_header(fp, formatspecs, skipchecksum=False):
         extras.append(_read_cstring(fp, delim).decode('UTF-8'))
     checksumtype = _read_cstring(fp, delim).decode('UTF-8')
     _header_cs = _read_cstring(fp, delim).decode('UTF-8')
+    # --- Strict check for magic+version against formatspecs ---
+    exp_magic = formatspecs.get('format_magic', '')
+    exp_ver = _normalize_ver_digits(_ver_digits(formatspecs.get('format_ver', '001')))
+    expected_magicver = exp_magic + exp_ver
+    if str(magicver) != str(expected_magicver):
+        raise ValueError(
+            "Bad archive header: magic/version mismatch (got {!r}, expected {!r})".format(magicver, expected_magicver)
+        )
     return {'fencoding': fencoding, 'fnumfiles': fnumfiles, 'fostype': fostype,
             'fextradata': extras, 'fchecksumtype': checksumtype,
             'ffilelist': [], 'fformatspecs': formatspecs}
